Module: AEMReference
- Defined in:
- lib/_aem/aemreference.rb
Defined Under Namespace
Classes: AND, AllElements, ApplicationRoot, BeginsWith, CollectComparable, ComparisonTest, Contains, CurrentContainer, CustomRoot, DeferredSpecifier, ElementByID, ElementByIndex, ElementByName, ElementByOrdinal, ElementByRelativePosition, ElementsByFilter, ElementsByRange, EndsWith, Equals, GreaterOrEquals, GreaterThan, InsertionSpecifier, IsIn, LessOrEquals, LessThan, LogicalTest, MultipleElements, NOT, NotEquals, OR, ObjectBeingExamined, PositionSpecifier, Property, Query, ReferenceRoot, SingleElement, Specifier, Test, UnkeyedElements, UserProperty
Constant Summary collapse
- App =
Reference root objects; used to construct new specifiers, e.g. AEM.app.property(‘pnam’)
ApplicationRoot.new
- Con =
CurrentContainer.new
- Its =
ObjectBeingExamined.new
Class Method Summary collapse
Class Method Details
.pack_list_as(type, lst) ⇒ Object
57 58 59 60 61 62 63 64 |
# File 'lib/_aem/aemreference.rb', line 57 def AEMReference.pack_list_as(type, lst) # used to pack object specifiers, etc. # pack key-value pairs into an AEListDesc, then coerce it to the desired type # (there are other AEM APIs for packing obj specs, but this way is easiest) desc = AE::AEDesc.new_list(true) lst.each { |key, value| desc.put_param(key, value) } return desc.coerce(type) end |