Class: AEMReference::CollectComparable
- Inherits:
-
Object
- Object
- AEMReference::CollectComparable
- Defined in:
- lib/_aem/aemreference.rb
Instance Attribute Summary collapse
-
#result ⇒ Object
readonly
obtains the data needed to perform equality tests on references uses AEM_resolve to walk a reference, building up a list of method call names and their arguments.
Instance Method Summary collapse
-
#initialize ⇒ CollectComparable
constructor
A new instance of CollectComparable.
- #send(name, *args) ⇒ Object
Constructor Details
#initialize ⇒ CollectComparable
Returns a new instance of CollectComparable.
72 73 74 |
# File 'lib/_aem/aemreference.rb', line 72 def initialize @result = [] end |
Instance Attribute Details
#result ⇒ Object (readonly)
obtains the data needed to perform equality tests on references uses AEM_resolve to walk a reference, building up a list of method call names and their arguments
70 71 72 |
# File 'lib/_aem/aemreference.rb', line 70 def result @result end |
Instance Method Details
#send(name, *args) ⇒ Object
76 77 78 79 |
# File 'lib/_aem/aemreference.rb', line 76 def send(name, *args) self.result.push([name] + args) return self end |